==> nocc-1.8.3.tbz: www/nocc/lang/dsb.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: dsb.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Lower Sorbian (Dolnoserbski)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Michawiki
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Pólo wužywarskego mjenja jo prozne';
$err_passwd_empty = 'Pólo gronidło jo prozne';
$alt_delete = 'Wubrane powěsći lašowaś';
$alt_delete_one = 'Powěsć lašowaś';
$alt_new_msg = 'Nowe powěsći';
$alt_reply = 'Awtoroju wótegroniś';
$alt_reply_all = 'Wšym wótegroniś';
$alt_forward = 'Dalej pósrědniś';
$alt_next = 'Pśiducy';
$alt_prev = 'Pjerwjejšny';
$title_next_page = 'Pśiducy bok';
$title_prev_page = 'Pjerwjejšny bok';
$title_next_msg = 'Pśiduca powěsć';
$title_prev_msg = 'Pjerwjejšna powěsć';
$html_theme_label = 'Tema:';
$html_welcome = 'Witaj do %1$s';
$html_login = 'Pśizjawjenje';
$html_user_label = 'Wužywaŕ:';
$html_passwd_label = 'Gronidło:';
$html_submit = 'Wótpósłaś';
$html_help = 'Pomoc';
$html_server_label = 'Serwer:';
$html_wrong = 'Wužywarske mě abo gronidło jo wopak';
$html_retry = 'Hyšći raz';
$html_remember = 'Nastajenja składowaś';
$html_lang_label = 'Rěc:';
$html_msgperpage_label = 'Powěsći na bok:';
$html_preferences = 'Nastajenja';
$html_full_name_label = 'Dopołne mě:';
$html_email_address_label = 'E-mailowa adresa:';
$html_ccself = 'Kopiju se pósłaś';
$html_hide_addresses = 'Adrese schowaś';
$html_outlook_quoting = 'Citaty w stilu Outlook';
$html_reply_to = 'Wótegroniś na';
$html_use_signature = 'Signaturu wužywaś';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura:';
$html_reply_leadin_label = 'Zawjeźenje wótegrona:';
$html_prefs_updated = 'Nastajenja zaktualizěrowane';
$html_manage_folders_link = 'IMAP-zarědniki zastojaś';
$html_manage_filters_link = 'E-mailowe filtry zastojaś';
$html_use_graphical_smilies = 'Grafiske smějacki wužywaś';
$html_sent_folder_label = 'Pósłane e-maile do póstajonego zarědnika kopěrowaś:';
$html_trash_folder_label = 'Wulašowane e-maile do póstajonego zarědnika pśesunuś:';
$html_colored_quotes = 'Barwojte citaty';
$html_display_struct = 'Strukturěrowany tekst zwobrazniś';
$html_send_html_mail = 'E-mail w HTML-formaśe pósłaś';
$html_folders = 'Zarědniki';
$html_folders_create_failed = 'Njejo móžno było zarědnik załožyś!';
$html_folders_sub_failed = 'Njejo móžno było zarědnik aboněrowaś!';
$html_folders_unsub_failed = 'Njejo móžno było zarědnik wótskazaś!';
$html_folders_rename_failed = 'Njejo móžno było zarědnik pśemjenowaś!';
$html_folders_updated = 'Zarědniki zaktualizěrowane';
$html_folder_subscribe = 'Aboněrowaś';
$html_folder_rename = 'Pśemjenowaś';
$html_folder_create = 'Załož nowy zarědnik z mjenim';
$html_folder_remove = 'Wótskazaś';
$html_folder_delete = 'Wulašowaś';
$html_folder_to = 'do';
$html_filter_remove = 'Wulašowaś';
$html_filter_body = 'Tekst powěsći';
$html_filter_subject = 'Tema powěsći';
$html_filter_to = 'Pólo Komu';
$html_filter_cc = 'Pólo Kopija';
$html_filter_from = 'Pólo Wót';
$html_filter_change_tip = 'Aby změnił filter, pśepiš jen jadnorje.';
$html_reapply_filters = 'Wšykne filtry znowego nałožyś';
$html_filter_contains = 'wopśimujo';
$html_filter_name = 'Mě filtra';
$html_filter_action = 'Akcija filtra';
$html_filter_moveto = 'Pśesunuś do';
$html_select_one = '--Wubraś--';
$html_and = 'A';
$html_new_msg_in = 'Nowe powěsći w';
$html_or = 'abo';
$html_move = 'Pśesunuś';
$html_copy = 'Kopěrowaś';
$html_messages_to = 'markěrowane powěsći do';
$html_gotopage = 'Źi k bokoju';
$html_gotofolder = 'Źi k zarědnikoju';
$html_other_folders = 'Lisćina zarědnikow';
$html_page = 'Bok';
$html_of = 'z';
$html_view_header = 'Głowu se woglědaś';
$html_remove_header = 'Głowu schowaś';
$html_inbox = 'Pśiwzete powěsći';
$html_new_msg = 'Pisaś';
$html_reply = 'Wótegroniś';
$html_reply_short = 'Re:';
$html_reply_all = 'Wšym wótegroniś';
$html_forward = 'Dalej pósrědniś';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Dalej pósrědnjona powěsć buźo se ako dodank k toś tej powěsći słaś.';
$html_delete = 'Wulašowaś';
$html_new = 'Nowy';
$html_mark = 'Wulašowaś';
$html_att_label = 'Dodank:';
$html_atts_label = 'Dodanki:';
$html_unknown = '[njeznaty]';
$html_attach = 'Dodaś';
$html_attach_forget = 'Musyš swóju dataju do wótpósćelanja swójeje powěsći dodaś!';
$html_attach_delete = 'Wubrane wótpóraś';
$html_attach_none = 'Musyš dataju wubraś, aby ju dodał!';
$html_sort_by = 'Sortěrowaś pó';
$html_sort = 'Sortěrowaś';
$html_from = 'Wót';
$html_from_label = 'Wót:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Pósłany:';
$html_wrote = 'jo napisał';
$html_size = 'Wjelikosć';
$html_totalsize = 'Cełkowna wjelikosć';
$html_kb = 'KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajty';
$html_filename = 'Datajowe mě';
$html_to = 'Komu';
$html_to_label = 'Komu:';
$html_cc = 'Kopija';
$html_cc_label = 'Kopija:';
$html_bcc_label = 'Schowana kopija:';
$html_nosubject = 'Žedna tema';
$html_send = 'Pósłaś';
$html_cancel = 'Pśetergnuś';
$html_no_mail = 'Žedna powěsć.';
$html_logout = 'Wótzjawjenje';
$html_msg = 'Powěsć';
$html_msgs = 'Powěsći';
$html_configuration = 'Toś ten serwer njejo pšawje skonfigurěrowany!';
$html_priority = 'Priorita';
$html_priority_label = 'Priorita:';
$html_lowest = 'Nejniša';
$html_low = 'Niska';
$html_normal = 'Normalna';
$html_high = 'Wusoka';
$html_highest = 'Nejwuša';
$html_flagged = 'Markěrowany';
$html_spam = 'Spam';
$html_spam_warning = 'Toś ta powěsć jo se klasificěrowała ako spam.';
$html_receipt = 'Wobtwarźenje dostaśa pominaś';
$html_select = 'Wubraś';
$html_select_all = 'Wuběrk pśewobrośiś';
$html_select_contacts = 'Kontakty wubraś';
$html_loading_image = 'Wobraz se zacytujo';
$html_send_confirmed = 'Twója e-mail jo se za rozpósłanje akceptěrowała';
$html_no_sendaction = 'Žedna akcija pódana. Wopytaj JavaScript zmóžniś.';
$html_error_occurred = 'Zmólka jo nastała.';
$html_prefs_file_error = 'Njejo móžno dataju nastajenjow za pisanje wócyniś.';
$html_wrap = 'Licba znamuškow, pó kótarejž maju se wuchadajuce powěsći łamaś:';
$html_wrap_none = 'Žedno łamanje';
$html_usenet_separator = 'Źěleńske znamuško Useneta ("-- \n") pśed signaturu';
$html_mark_as = 'Markěrowaś ako';
$html_read = 'pśecytany';
$html_unread = 'njepśecytany';
$html_encoding_label = 'Koděrowanje znamuškow:';
$html_add = 'Pśidaś';
$html_contacts = 'Kontakty $1$s';
$html_modify = 'Změniś';
$html_back = 'Slědk';
$html_contact_add = 'Nowy kontakt pśidaś';
$html_contact_mod = 'Kontakt změniś';
$html_contact_first = 'Pśedmě';
$html_contact_last = 'Familijowe mě';
$html_contact_nick = 'Pśimě';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Lisćina kontaktow wužywarja $1$s';
$html_contact_del = 'z lisćiny kontaktow';
$html_contact_count = '%1$d kontaktow';
$html_contact_err1 = 'Maksimalna licba kontaktow jo "%1$d"';
$html_contact_err2 = 'Njamóžoš nowy kontakt pśidaś';
$html_contact_err3 = 'Njamaš pśistupne pšawa za lisćinu kontaktow';
$html_contact_none = 'Njejo móžno było kontakty namakaś.';
$html_del_msg = 'Wubrane powěsći lašowaś?';
$html_down_mail = 'Ześěgnuś';
$original_msg = '-- Originalna powěsć --';
$to_empty = 'Pólo "Komu" njesmějo prozne byś!';
$html_images_warning = 'Za twóju wěstotu eksterne wobraze se njezwobraznjuju.';
$html_images_display = 'Wobraze zwobrazniś';
$html_smtp_error_no_conn = 'Njejo móžno zwisk SMTP wócyniś.';
$html_smtp_error_unexpected = 'Njewócakane wótegrono SMTP:';
$lang_could_not_connect = 'Zwisk k serweroju jo se njeraźił';
$lang_invalid_msg_num = 'Wopacny powěsćowy numer';
$html_file_upload_attack = 'Móžny napad pśi nagrawanju dataje';
$html_invalid_email_address = 'Njepłaśiwa e-mailowa adresa';
$html_invalid_msg_per_page = 'Njepłaśiwa licba powěsćow na bok';
$html_invalid_wrap_msg = 'Njepłaśiwe powěsćowe łamanje';
$html_seperate_msg_win = 'Powěsći w nowem woknje';
$html_err_file_contacts = 'Njejo móžno dataju kontaktow za pisanje wócyniś.';
$html_session_file_error = 'Njejo móžno pósejźeńsku dataju za pisanje wócyniś.';
$html_login_not_allowed = 'Toś to pśizjawjenje njejo za zwisk pśizwólone.';
$lang_err_send_delay = 'Musyš mjazy dwěma e-mailoma cakaś (%1$d sekundow)';
$html_search = 'Pytaś';

==> nocc-1.9.1.tbz: www/nocc/lang/dsb.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: dsb.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Lower Sorbian (Dolnoserbski)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Michawiki
 */

$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Pólo wužywarskego mjenja jo prozne';
$err_passwd_empty = 'Pólo gronidło jo prozne';
$alt_delete = 'Wubrane powěsći lašowaś';
$alt_delete_one = 'Powěsć lašowaś';
$alt_new_msg = 'Nowe powěsći';
$alt_reply = 'Awtoroju wótegroniś';
$alt_reply_all = 'Wšym wótegroniś';
$alt_forward = 'Dalej pósrědniś';
$alt_next = 'Pśiducy';
$alt_prev = 'Pjerwjejšny';
$title_next_page = 'Pśiducy bok';
$title_prev_page = 'Pjerwjejšny bok';
$title_next_msg = 'Pśiduca powěsć';
$title_prev_msg = 'Pjerwjejšna powěsć';
$html_theme_label = 'Tema:';
$html_welcome = 'Witaj do %1$s';
$html_login = 'Pśizjawjenje';
$html_user_label = 'Wužywaŕ:';
$html_passwd_label = 'Gronidło:';
$html_submit = 'Wótpósłaś';
$html_help = 'Pomoc';
$html_server_label = 'Serwer:';
$html_wrong = 'Wužywarske mě abo gronidło jo wopak';
$html_retry = 'Hyšći raz';
$html_remember = 'Nastajenja składowaś';
$html_lang_label = 'Rěc:';
$html_msgperpage_label = 'Powěsći na bok:';
$html_preferences = 'Nastajenja';
$html_full_name_label = 'Dopołne mě:';
$html_email_address_label = 'E-mailowa adresa:';
$html_bccself = 'Schowanu kopiju se pósłaś';
$html_hide_addresses = 'Adrese schowaś';
$html_outlook_quoting = 'Citaty w stilu Outlook';
$html_reply_to = 'Wótegroniś na';
$html_use_signature = 'Signaturu wužywaś';
$html_signature = 'Signatura';
$html_signature_label = 'Signatura:';
$html_reply_leadin_label = 'Zawjeźenje wótegrona:';
$html_prefs_updated = 'Nastajenja zaktualizěrowane';
$html_manage_folders_link = 'IMAP-zarědniki zastojaś';
$html_manage_filters_link = 'E-mailowe filtry zastojaś';
$html_use_graphical_smilies = 'Grafiske smějacki wužywaś';
$html_sent_folder_label = 'Pósłane e-maile do póstajonego zarědnika kopěrowaś:';
$html_trash_folder_label = 'Wulašowane e-maile do póstajonego zarědnika pśesunuś:';
$html_colored_quotes = 'Barwojte citaty';
$html_display_struct = 'Strukturěrowany tekst zwobrazniś';
$html_send_html_mail = 'E-mail w HTML-formaśe pósłaś';
$html_folders = 'Zarědniki';
$html_folders_create_failed = 'Njejo móžno było zarědnik załožyś!';
$html_folders_sub_failed = 'Njejo móžno było zarědnik aboněrowaś!';
$html_folders_unsub_failed = 'Njejo móžno było zarědnik wótskazaś!';
$html_folders_rename_failed = 'Njejo móžno było zarědnik pśemjenowaś!';
$html_folders_updated = 'Zarědniki zaktualizěrowane';
$html_folder_subscribe = 'Aboněrowaś';
$html_folder_rename = 'Pśemjenowaś';
$html_folder_create = 'Załož nowy zarědnik z mjenim';
$html_folder_remove = 'Wótskazaś';
$html_folder_delete = 'Wulašowaś';
$html_folder_to = 'do';
$html_filter_remove = 'Wulašowaś';
$html_filter_body = 'Tekst powěsći';
$html_filter_subject = 'Tema powěsći';
$html_filter_to = 'Pólo Komu';
$html_filter_cc = 'Pólo Kopija';
$html_filter_from = 'Pólo Wót';
$html_filter_change_tip = 'Aby změnił filter, pśepiš jen jadnorje.';
$html_reapply_filters = 'Wšykne filtry znowego nałožyś';
$html_filter_contains = 'wopśimujo';
$html_filter_name = 'Mě filtra';
$html_filter_action = 'Akcija filtra';
$html_filter_moveto = 'Pśesunuś do';
$html_select_one = '--Wubraś--';
$html_and = 'A';
$html_new_msg_in = 'Nowe powěsći w';
$html_or = 'abo';
$html_move = 'Pśesunuś';
$html_copy = 'Kopěrowaś';
$html_messages_to = 'markěrowane powěsći do';
$html_gotopage = 'Źi k bokoju';
$html_gotofolder = 'Źi k zarědnikoju';
$html_other_folders = 'Lisćina zarědnikow';
$html_page = 'Bok';
$html_of = 'z';
$html_view_header = 'Głowu se woglědaś';
$html_remove_header = 'Głowu schowaś';
$html_inbox = 'Pśiwzete powěsći';
$html_new_msg = 'Pisaś';
$html_reply = 'Wótegroniś';
$html_reply_short = 'Re:';
$html_reply_all = 'Wšym wótegroniś';
$html_forward = 'Dalej pósrědniś';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Dalej pósrědnjona powěsć buźo se ako dodank k toś tej powěsći słaś.';
$html_delete = 'Wulašowaś';
$html_new = 'Nowy';
$html_mark = 'Wulašowaś';
$html_att_label = 'Dodank:';
$html_atts_label = 'Dodanki:';
$html_unknown = '[njeznaty]';
$html_part_x = 'Źěl %s';
$html_attach = 'Dodaś';
$html_attach_forget = 'Musyš swóju dataju do wótpósćelanja swójeje powěsći dodaś!';
$html_attach_delete = 'Wubrane wótpóraś';
$html_attach_none = 'Musyš dataju wubraś, aby ju dodał!';
$html_sort_by = 'Sortěrowaś pó';
$html_sort = 'Sortěrowaś';
$html_from = 'Wót';
$html_from_label = 'Wót:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Pósłany:';
$html_wrote = 'jo napisał';
$html_size = 'Wjelikosć';
$html_totalsize = 'Cełkowna wjelikosć';
$html_kb = 'KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajty';
$html_filename = 'Datajowe mě';
$html_to = 'Komu';
$html_to_label = 'Komu:';
$html_cc = 'Kopija';
$html_cc_label = 'Kopija:';
$html_bcc_label = 'Schowana kopija:';
$html_nosubject = 'Žedna tema';
$html_send = 'Pósłaś';
$html_cancel = 'Pśetergnuś';
$html_no_mail = 'Žedna powěsć.';
$html_logout = 'Wótzjawjenje';
$html_msg = 'Powěsć';
$html_msgs = 'Powěsći';
$html_configuration = 'Toś ten serwer njejo pšawje skonfigurěrowany!';
$html_priority = 'Priorita';
$html_priority_label = 'Priorita:';
$html_lowest = 'Nejniša';
$html_low = 'Niska';
$html_normal = 'Normalna';
$html_high = 'Wusoka';
$html_highest = 'Nejwuša';
$html_flagged = 'Markěrowany';
$html_spam = 'Spam';
$html_spam_warning = 'Toś ta powěsć jo se klasificěrowała ako spam.';
$html_receipt = 'Wobtwarźenje dostaśa pominaś';
$html_select = 'Wubraś';
$html_select_all = 'Wuběrk pśewobrośiś';
$html_select_contacts = 'Kontakty wubraś';
$html_loading_image = 'Wobraz se zacytujo';
$html_send_confirmed = 'Twója e-mail jo se za rozpósłanje akceptěrowała';
$html_no_sendaction = 'Žedna akcija pódana. Wopytaj JavaScript zmóžniś.';
$html_error_occurred = 'Zmólka jo nastała.';
$html_prefs_file_error = 'Njejo móžno dataju nastajenjow za pisanje wócyniś.';
$html_wrap = 'Licba znamuškow, pó kótarejž maju se wuchadajuce powěsći łamaś:';
$html_wrap_none = 'Žedno łamanje';
$html_usenet_separator = 'Źěleńske znamuško Useneta ("-- \n") pśed signaturu';
$html_mark_as = 'Markěrowaś ako';
$html_read = 'pśecytany';
$html_unread = 'njepśecytany';
$html_encoding_label = 'Koděrowanje znamuškow:';
$html_add = 'Pśidaś';
$html_contacts = 'Kontakty $1$s';
$html_modify = 'Změniś';
$html_back = 'Slědk';
$html_contact_add = 'Nowy kontakt pśidaś';
$html_contact_mod = 'Kontakt změniś';
$html_contact_first = 'Pśedmě';
$html_contact_last = 'Familijowe mě';
$html_contact_nick = 'Pśimě';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Lisćina kontaktow wužywarja $1$s';
$html_contact_del = 'z lisćiny kontaktow';
$html_contact_count = '%1$d kontaktow';
$html_contact_err1 = 'Maksimalna licba kontaktow jo "%1$d"';
$html_contact_err2 = 'Njamóžoš nowy kontakt pśidaś';
$html_contact_err3 = 'Njamaš pśistupne pšawa za lisćinu kontaktow';
$html_contact_none = 'Njejo móžno było kontakty namakaś.';
$html_del_msg = 'Wubrane powěsći lašowaś?';
$html_down_mail = 'Ześěgnuś';
$original_msg = '-- Originalna powěsć --';
$to_empty = 'Pólo "Komu" njesmějo prozne byś!';
$html_images_warning = 'Za twóju wěstotu eksterne wobraze se njezwobraznjuju.';
$html_images_display = 'Wobraze zwobrazniś';
$html_smtp_error_no_conn = 'Njejo móžno zwisk SMTP wócyniś.';
$html_smtp_error_unexpected = 'Njewócakane wótegrono SMTP:';
$lang_could_not_connect = 'Zwisk k serweroju jo se njeraźił';
$lang_invalid_msg_num = 'Wopacny powěsćowy numer';
$html_file_upload_attack = 'Móžny napad pśi nagrawanju dataje';
$html_invalid_email_address = 'Njepłaśiwa e-mailowa adresa';
$html_invalid_msg_per_page = 'Njepłaśiwa licba powěsćow na bok';
$html_invalid_wrap_msg = 'Njepłaśiwe powěsćowe łamanje';
$html_seperate_msg_win = 'Powěsći w nowem woknje';
$html_err_file_contacts = 'Njejo móžno dataju kontaktow za pisanje wócyniś.';
$html_session_file_error = 'Njejo móžno pósejźeńsku dataju za pisanje wócyniś.';
$html_login_not_allowed = 'Toś to pśizjawjenje njejo za zwisk pśizwólone.';
$lang_err_send_delay = 'Musyš mjazy dwěma e-mailoma cakaś (%1$d sekundow)';
$html_search = 'Pytaś';
